%define		real_name	Mail-SpamAssassin

Summary:	Spam filter for email which can be invoked from mail delivery agents.
Name:		spamassassin
Version:	3.2.5
Release:	1
License:	Apache License
Group:		Networking/Mail
URL:		http://spamassassin.apache.org/
Source0:	http://www.apache.org/dist/%{name}/%{real_name}-%{version}.tar.bz2
Source2:	ccux-local.cf
Source3:	spamassassin-default.rc
Source4:	spamassassin-spamc.rc
Source5:	spamassassin.sysconfig
Source6:	sa-update.logrotate
Source7:	sa-update.crontab
Source8:	sa-update.cronscript
Source10:	spamassassin-helper.sh

Buildroot:	%{_tmppath}/%{name}-root

Requires:	perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:	perl-Net-DNS
Requires:	procmail
Requires:	gnupg
Requires:	perl-HTML-Parser >= 3.43
Requires:	perl-IO-Socket-SSL
Requires:	perl-IO-Socket-INET6

BuildRequires:	e2fsprogs-devel

%{!?perl_vendorlib: %define perl_vendorlib %(eval "`%{__perl} -V:installvendorlib`"; echo $installvendorlib)}

# Automatically resolved build dependencies
BuildRequires: bash
BuildRequires: glibc-devel
BuildRequires: openssl-devel
BuildRequires: perl
BuildRequires: perl-Digest-SHA1
BuildRequires: perl-HTML-Parser
BuildRequires: perl-libwww-perl
BuildRequires: perl-Net-DNS
BuildRequires: zlib-devel

Requires(post):		diffutils
Requires(post):		/sbin/chkconfig
Requires(post):		/bin/mktemp

Requires(preun):		/sbin/chkconfig
Requires(preun):	/sbin/service

Requires(postun):	/sbin/service

%description
SpamAssassin provides you with a way to reduce if not completely eliminate
Unsolicited Commercial Email (SPAM) from your incoming email.  It can
be invoked by a MDA such as sendmail or postfix, or can be called from
a procmail script, .forward file, etc.  It uses a genetic-algorithm
evolved scoring system to identify messages which look spammy, then
adds headers to the message so they can be filtered by the user's mail
reading software.  This distribution includes the spamd/spamc components
which create a server that considerably speeds processing of mail.

To enable spamassassin, if you are receiving mail locally, simply add
this line to your ~/.procmailrc:
INCLUDERC=/etc/mail/spamassassin/spamassassin-default.rc

To filter spam for all users, add that line to /etc/procmailrc
(creating if necessary).

%post
/sbin/chkconfig --add spamassassin

# -a and --auto-whitelist options were removed from 3.0.0
# prevent service startup failure
TMPFILE=$(/usr/bin/mktemp /etc/sysconfig/spamassassin.XXXXXX) || exit 1
cp /etc/sysconfig/spamassassin $TMPFILE
perl -p -i -e 's/(["\s]-\w+)a/$1/ ; s/(["\s]-)a(\w+)/$1$2/ ; s/(["\s])-a\b/$1/' $TMPFILE
perl -p -i -e 's/ --auto-whitelist//' $TMPFILE
# replace /etc/sysconfig/spamassassin only if it actually changed
cmp /etc/sysconfig/spamassassin $TMPFILE || cp $TMPFILE /etc/sysconfig/spamassassin
rm $TMPFILE

if [ -f /etc/spamassassin.cf ]; then
	%{__mv} /etc/spamassassin.cf /etc/mail/spamassassin/migrated.cf
fi
if [ -f /etc/mail/spamassassin.cf ]; then
	%{__mv} /etc/mail/spamassassin.cf /etc/mail/spamassassin/migrated.cf
fi

%postun
if [ "$1" -ge "1" ]; then
    /sbin/service spamassassin condrestart > /dev/null 2>&1
fi
exit 0

%preun
if [ $1 = 0 ] ; then
    /sbin/service spamassassin stop >/dev/null 2>&1
    /sbin/chkconfig --del spamassassin
fi
exit 0


%prep
%setup -q -n %{real_name}-%{version}

%build
export CFLAGS="$RPM_OPT_FLAGS"
perl Makefile.PL %_prefix ENABLE_SSL=yes < /dev/null
make

%install
rm -Rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%_initrddir
install -m 0755 spamd/redhat-rc-script.sh $RPM_BUILD_ROOT%_initrddir/spamassassin

mkdir -p $RPM_BUILD_ROOT%_sysconfdir/mail/spamassassin
mkdir -p $RPM_BUILD_ROOT%_sysconfdir/sysconfig
mkdir -p $RPM_BUILD_ROOT%_sysconfdir/logrotate.d
# mkdir -p $RPM_BUILD_ROOT%_sysconfdir/cron.d
mkdir -p $RPM_BUILD_ROOT%_datadir/%{name}
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%_sysconfdir/mail/spamassassin/local.cf
install -m644 %{SOURCE5} $RPM_BUILD_ROOT%_sysconfdir/sysconfig/spamassassin

install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%_sysconfdir/mail/spamassassin
install -m 0644 %{SOURCE4} $RPM_BUILD_ROOT%_sysconfdir/mail/spamassassin
install -m 0755 %{SOURCE10} $RPM_BUILD_ROOT%_sysconfdir/mail/spamassassin
install -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%_sysconfdir/logrotate.d/sa-update
# install -m 0600 %{SOURCE7} $RPM_BUILD_ROOT%_sysconfdir/cron.d/sa-update
install -m 0744 %{SOURCE8} $RPM_BUILD_ROOT%_datadir/spamassassin/sa-update.cron

# removing unwanted stuff
if [ -f $RPM_BUILD_ROOT%_libdir/perl5/*/*/perllocal.pod ]; then
	rm -f $RPM_BUILD_ROOT%_libdir/perl5/*/*/perllocal.pod
fi

%files
%defattr(-,root,root)
%doc LICENSE NOTICE CREDITS Changes README TRADEMARK UPGRADE
%doc USAGE sample-nonspam.txt sample-spam.txt
%_sysconfdir
%_bindir
%_libdir
%_mandir
%_datadir/%{name}

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Fri Oct 17 2008 Christian Wasem <wasem@ccux-linux.de> 3.2.5-1
- Version update
* Mon Apr 28 2008 Christian Wasem <wasem@ccux-linux.de> 3.2.4-1
- Initial release
